==> qmmp-0.9.8.tar.bz2: qmmp-0.9.8/src/plugins/Visual/projectm/translations/projectm_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Show Song Title</source>
        <translation>显示歌曲标题(&amp;S)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Show Preset Name</source>
        <translation>显示边框形式名称(&amp;S)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Show Menu</source>
        <translation>&amp;显示菜单</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>&amp;Next Preset</source>
        <translation>下一边框形式(&amp;N)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Previous Preset</source>
        <translation>上一边框形式(&amp;P)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>&amp;Random Preset</source>
        <translation>随意边框形式(&amp;R)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>&amp;Lock Preset</source>
        <translation>锁定边框形式(&amp;L)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>&amp;Fullscreen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>projectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>关于 ProjectM 可视化插件</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Qmmp ProjectM 可视化插件</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>此插件添加 projectM 可视化</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>基于 libprojectM-qt 库</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Visual/projectm/translations/projectm_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="161"/>
        <source>&amp;Show Song Title</source>
        <translation>显示歌曲标题(&amp;S)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="161"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="162"/>
        <source>&amp;Show Preset Name</source>
        <translation>显示边框形式名称(&amp;S)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="162"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="163"/>
        <source>&amp;Show Menu</source>
        <translation>显示菜单(&amp;S)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="163"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Next Preset</source>
        <translation>下一边框形式(&amp;N)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Previous Preset</source>
        <translation>上一边框形式(&amp;P)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Random Preset</source>
        <translation>随意边框形式(&amp;R)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="168"/>
        <source>&amp;Lock Preset</source>
        <translation>锁定边框形式(&amp;L)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="168"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Fullscreen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="30"/>
        <source>ProjectM</source>
        <translation>projectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>关于 ProjectM 可视化插件</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Qmmp ProjectM 可视化插件</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>This plugin adds projectM visualization</source>
        <translation>此插件添加 projectM 可视化</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="54"/>
        <source>Based on libprojectM-qt library</source>
        <translation>基于 libprojectM-qt 库</translation>
    </message>
</context>
</TS>
